==> huaweicloudsdkvpc-3.0.51-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_security_group_rule_request.py <==
# coding: utf-8

import re
import six





class DeleteSecurityGroupRuleRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'security_group_rule_id': 'str'
    }

    attribute_map = {
        'security_group_rule_id': 'security_group_rule_id'
    }

    def __init__(self, security_group_rule_id=None):
        """DeleteSecurityGroupRuleRequest - a model defined in huaweicloud sdk"""
        
        

        self._security_group_rule_id = None
        self.discriminator = None

        self.security_group_rule_id = security_group_rule_id

    @property
    def security_group_rule_id(self):
        """Gets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID

        :return: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :rtype: str
        """
        return self._security_group_rule_id

    @security_group_rule_id.setter
    def security_group_rule_id(self, security_group_rule_id):
        """Sets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID

        :param security_group_rule_id: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :type: str
        """
        self._security_group_rule_id = security_group_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecurityGroupRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.38-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_security_group_rule_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSecurityGroupRuleRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'security_group_rule_id': 'str'
    }

    attribute_map = {
        'security_group_rule_id': 'security_group_rule_id'
    }

    def __init__(self, security_group_rule_id=None):
        """DeleteSecurityGroupRuleRequest

        The model defined in huaweicloud sdk

        :param security_group_rule_id: 安全组规则ID
        :type security_group_rule_id: str
        """
        
        

        self._security_group_rule_id = None
        self.discriminator = None

        self.security_group_rule_id = security_group_rule_id

    @property
    def security_group_rule_id(self):
        """Gets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID

        :return: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :rtype: str
        """
        return self._security_group_rule_id

    @security_group_rule_id.setter
    def security_group_rule_id(self, security_group_rule_id):
        """Sets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID

        :param security_group_rule_id: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :type security_group_rule_id: str
        """
        self._security_group_rule_id = security_group_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecurityGroupRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
